<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}">
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>{{ config('app.name', 'Kylin App') }}</title>
    @vite(['resources/css/app.css', 'resources/js/app.js'])
</head>
<body class="bg-light">
    <div class="d-flex align-items-center justify-content-center vh-100">
        <div class="text-center">
            <h1 class="display-4 fw-bold text-primary">Kylin</h1>
            <p class="lead text-muted">企业级应用开发平台</p>
            <a href="{{ route('login') ?? '/login' }}" class="btn btn-primary btn-lg mt-3">进入后台</a>
        </div>
    </div>
</body>
</html>
