<?php

use Illuminate\Support\Facades\Route;

// API 路由 - 已由各 Kylin 包自动注册
// 如需自定义 API 路由，在此添加

Route::get('/health', function () {
    return response()->json(['status' => 'ok', 'time' => now()->toIso8601String()]);
});
